@@ -1,6 +1,7 @@
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  XMonad.Actions.Commands
+-- Description :  Run internal xmonad commands using a dmenu menu.
 -- Copyright   :  (c) David Glasser 2007
 -- License     :  BSD3
 --
@@ -32,7 +33,7 @@ import XMonad.Util.Dmenu (dmenu)
 
 import qualified Data.Map as M
 import System.Exit
-import Data.Maybe
+import XMonad.Prelude
 
 -- $usage
 --
@@ -61,18 +62,18 @@ import Data.Maybe
 -- | Create a 'Data.Map.Map' from @String@s to xmonad actions from a
 --   list of pairs.
 commandMap :: [(String, X ())] -> M.Map String (X ())
-commandMap c = M.fromList c
+commandMap = M.fromList
 
 -- | Generate a list of commands to switch to\/send windows to workspaces.
 workspaceCommands :: X [(String, X ())]
 workspaceCommands = asks (workspaces . config) >>= \spaces -> return
-                            [((m ++ show i), windows $ f i)
+                            [( m ++ show i, windows $ f i)
                                 | i <- spaces
                                 , (f, m) <- [(view, "view"), (shift, "shift")] ]
 
 -- | Generate a list of commands dealing with multiple screens.
 screenCommands :: [(String, X ())]
-screenCommands = [((m ++ show sc), screenWorkspace (fromIntegral sc) >>= flip whenJust (windows . f))
+screenCommands = [( m ++ show sc, screenWorkspace (fromIntegral sc) >>= flip whenJust (windows . f))
                       | sc <- [0, 1]::[Int] -- TODO: adapt to screen changes
                       , (f, m) <- [(view, "screen"), (shift, "screen-to-")]
                  ]
@@ -100,7 +101,7 @@ defaultCommands = do
         , ("swap-down"           , windows swapDown                                 )
         , ("swap-master"         , windows swapMaster                               )
         , ("sink"                , withFocused $ windows . sink                     )
-        , ("quit-wm"             , io $ exitWith ExitSuccess                        )
+        , ("quit-wm"             , io exitSuccess                                   )
         ]
 
 -- | Given a list of command\/action pairs, prompt the user to choose a
