@@ -124,7 +124,7 @@ import Data.Word (Word8)
 -- > ...
 -- > gsconfig1 = def { gs_cellheight = 30, gs_cellwidth = 100 }
 --
--- An example where 'buildDefaultGSConfig' is used instead of 'defaultGSConfig'
+-- An example where 'buildDefaultGSConfig' is used instead of 'def'
 -- in order to specify a custom colorizer is @gsconfig2@ (found in
 -- "XMonad.Actions.GridSelect#Colorizers"):
 --
@@ -285,11 +285,7 @@ orderElementmap searchString elements = if not $ null searchString then sortedEl
 
 
 newtype TwoD a b = TwoD { unTwoD :: StateT (TwoDState a) X b }
-    deriving (Monad,Functor,MonadState (TwoDState a))
-
-instance Applicative (TwoD a) where
-    (<*>) = ap
-    pure = return
+    deriving (Functor, Applicative, Monad, MonadState (TwoDState a))
 
 liftX ::  X a1 -> TwoD a a1
 liftX = TwoD . lift
@@ -411,10 +407,11 @@ makeXEventhandler keyhandler = fix $ \me -> join $ liftX $ withDisplay $ \d -> l
                              ev <- getEvent e
                              if ev_event_type ev == keyPress
                                then do
-                                  (ks,s) <- lookupString $ asKeyEvent e
+                                  (_, s) <- lookupString $ asKeyEvent e
+                                  ks <- keycodeToKeysym d (ev_keycode ev) 0
                                   return $ do
-                                      mask <- liftX $ cleanMask (ev_state ev)
-                                      keyhandler (fromMaybe xK_VoidSymbol ks, s, mask)
+                                      mask <- liftX $ cleanKeyMask <*> pure (ev_state ev)
+                                      keyhandler (ks, s, mask)
                                else
                                   return $ stdHandle ev me
 
