@@ -1,6 +1,7 @@
 -----------------------------------------------------------------------------
 -- |
 -- Module       : XMonad.Actions.MessageFeedback
+-- Description :  An alternative @sendMessage@.
 -- Copyright    : (c) --   Quentin Moser <moserq@gmail.com>
 --                    2018 Yclept Nemo
 -- License      : BSD3
@@ -51,13 +52,11 @@ module XMonad.Actions.MessageFeedback
 
 import XMonad               ( Window )
 import XMonad.Core          ( X(), Message, SomeMessage(..), LayoutClass(..), windowset, catchX, WorkspaceId, Layout, whenJust )
-import XMonad.StackSet      ( Workspace, current, workspace, layout, tag )
 import XMonad.Operations    ( updateLayout, windowBracket, modifyWindowSet )
+import XMonad.Prelude       ( isJust, liftA2, void )
+import XMonad.StackSet      ( Workspace, current, workspace, layout, tag )
 
-import Data.Maybe           ( isJust )
-import Control.Monad        ( void )
 import Control.Monad.State  ( gets )
-import Control.Applicative  ( (<$>), liftA2 )
 
 -- $usage
 -- You can use this module with the following in your @~\/.xmonad\/xmonad.hs@:
@@ -108,7 +107,7 @@ import Control.Applicative  ( (<$>), liftA2 )
 -- 'XMonad.Operations.sendMessage' code - foregoes the O(n) 'updateLayout'.
 sendSomeMessageB :: SomeMessage -> X Bool
 sendSomeMessageB m = windowBracket id $ do
-    w  <- workspace . current <$> gets windowset
+    w  <- gets ((workspace . current) . windowset)
     ml <- handleMessage (layout w) m `catchX` return Nothing
     whenJust ml $ \l ->
         modifyWindowSet $ \ws -> ws { current = (current ws)
@@ -140,7 +139,7 @@ sendSomeMessageWithNoRefresh m = void . sendSomeMessageWithNoRefreshB m
 -- 'XMonad.Operations.sendMessageWithNoRefresh' (does not refresh).
 sendSomeMessageWithNoRefreshToCurrentB :: SomeMessage -> X Bool
 sendSomeMessageWithNoRefreshToCurrentB m
-    =   (gets $ workspace . current . windowset)
+    =   gets (workspace . current . windowset)
     >>= sendSomeMessageWithNoRefreshB m
 
 -- | Variant of 'sendSomeMessageWithNoRefreshToCurrentB' that discards the
