@@ -1,8 +1,9 @@
-{-# LANGUAGE GeneralizedNewtypeDeriving, MultiParamTypeClasses, PatternGuards, TypeSynonymInstances #-}
+{-# LANGUAGE MultiParamTypeClasses, PatternGuards, TypeSynonymInstances #-}
 
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  XMonad.Actions.MouseResize
+-- Description :  A layout modifier to resize windows with the mouse.
 -- Copyright   :  (c) 2007 Andrea Rossato
 -- License     :  BSD-style (see xmonad/LICENSE)
 --
@@ -56,7 +57,7 @@ import XMonad.Util.XUtils
 mouseResize :: l a -> ModifiedLayout MouseResize l a
 mouseResize = ModifiedLayout (MR [])
 
-data MouseResize a = MR [((a,Rectangle),Maybe a)]
+newtype MouseResize a = MR [((a,Rectangle),Maybe a)]
 instance Show (MouseResize a) where show        _ = ""
 instance Read (MouseResize a) where readsPrec _ s = [(MR [], s)]
 
@@ -68,7 +69,7 @@ instance LayoutModifier MouseResize Window where
         where
           wrs'         = wrs_to_state [] . filter (isInStack s . fst) $ wrs
           initState    = mapM createInputWindow wrs'
-          processState = mapM (deleteInputWin . snd) st >> mapM createInputWindow wrs'
+          processState = mapM_ (deleteInputWin . snd) st >> mapM createInputWindow wrs'
 
           inputRectangle (Rectangle x y wh ht) = Rectangle (x + fi wh - 5) (y + fi ht - 5) 10 10
 
@@ -105,7 +106,7 @@ handleResize st ButtonEvent { ev_window = ew, ev_event_type = et }
 handleResize _ _ = return ()
 
 createInputWindow :: ((Window,Rectangle), Maybe Rectangle) -> X ((Window,Rectangle),Maybe Window)
-createInputWindow ((w,r),mr) = do
+createInputWindow ((w,r),mr) =
   case mr of
     Just tr  -> withDisplay $ \d -> do
                   tw <- mkInputWindow d tr
