@@ -1,6 +1,7 @@
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  XMonad.Actions.OnScreen
+-- Description :  Control workspaces on different screens (in xinerama mode).
 -- Copyright   :  (c) 2009 Nils Schweinsberg
 -- License     :  BSD3-style (see LICENSE)
 --
@@ -26,12 +27,9 @@ module XMonad.Actions.OnScreen (
     ) where
 
 import XMonad
+import XMonad.Prelude (fromMaybe, guard)
 import XMonad.StackSet hiding (new)
 
-import Control.Monad (guard)
--- import Control.Monad.State.Class (gets)
-import Data.Maybe (fromMaybe)
-
 
 -- | Focus data definitions
 data Focus = FocusNew                       -- ^ always focus the new screen
