@@ -1,6 +1,7 @@
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  XMonad.Actions.Plane
+-- Description :  Navigate through workspaces in a bidimensional manner.
 -- Copyright   :  (c) Marco Túlio Gontijo e Silva <marcot@riseup.net>,
 --                    Leonardo Serra <leoserra@minaslivre.org>
 -- License     :  BSD3-style (see LICENSE)
@@ -38,11 +39,9 @@ module XMonad.Actions.Plane
     )
     where
 
-import Control.Monad
-import Data.List
-import Data.Map hiding (split)
-import Data.Maybe
+import Data.Map (Map, fromList)
 
+import XMonad.Prelude
 import XMonad
 import XMonad.StackSet hiding (workspaces)
 import XMonad.Util.Run
