@@ -298,7 +298,7 @@ debpts        = searchEngine "debpts"        "https://packages.qa.debian.org/"
 dictionary    = searchEngine "dict"          "https://dictionary.reference.com/browse/"
 ebay          = searchEngine "ebay"          "https://www.ebay.com/sch/i.html?_nkw="
 github        = searchEngine "github"        "https://github.com/search?q="
-google        = searchEngine "google"        "https://www.google.com/search?num=100&q="
+google        = searchEngine "google"        "https://www.google.com/search?q="
 hackage       = searchEngine "hackage"       "https://hackage.haskell.org/package/"
 hoogle        = searchEngine "hoogle"        "https://hoogle.haskell.org/?hoogle="
 images        = searchEngine "images"        "https://images.google.fr/images?q="
