@@ -1,6 +1,7 @@
 -----------------------------------------------------------------------------
 -- |
 -- Module       : XMonad.Actions.TagWindows
+-- Description  : Functions for tagging windows and selecting them by tags.
 -- Copyright    : (c) Karsten Schoelzel <kuser@gmx.de>
 -- License      : BSD
 --
@@ -26,14 +27,12 @@ module XMonad.Actions.TagWindows (
                  TagPrompt,
                  ) where
 
-import Data.List (nub,sortBy)
-import Control.Monad
 import Control.Exception as E
 
-import XMonad.StackSet hiding (filter)
-
-import XMonad.Prompt
 import XMonad hiding (workspaces)
+import XMonad.Prelude
+import XMonad.Prompt
+import XMonad.StackSet hiding (filter)
 
 econst :: Monad m => a -> IOException -> m a
 econst = const . return
@@ -84,18 +83,17 @@ getTags w = withDisplay $ \d ->
     io $ E.catch (internAtom d "_XMONAD_TAGS" False >>=
                 getTextProperty d w >>=
                 wcTextPropertyToTextList d)
-               (econst [[]])
-    >>= return . words . unwords
+               (econst [[]]) <&> (words . unwords)
 
 -- | check a window for the given tag
 hasTag :: String -> Window -> X Bool
-hasTag s w = (s `elem`) `fmap` getTags w
+hasTag s w = (s `elem`) <$> getTags w
 
 -- | add a tag to the existing ones
 addTag :: String -> Window -> X ()
 addTag s w = do
     tags <- getTags w
-    if (s `notElem` tags) then setTags (s:tags) w else return ()
+    when (s `notElem` tags) $ setTags (s:tags) w
 
 -- | remove a tag from a window, if it exists
 delTag :: String -> Window -> X ()
@@ -158,7 +156,7 @@ withTagged' t m = gets windowset >>= filterM (hasTag t) . index >>= m
 
 withTaggedGlobal' :: String -> ([Window] -> X ()) -> X ()
 withTaggedGlobal' t m = gets windowset >>=
-    filterM (hasTag t) . concat . map (integrate' . stack) . workspaces >>= m
+    filterM (hasTag t) . concatMap (integrate' . stack) . workspaces >>= m
 
 withFocusedP :: (Window -> WindowSet -> WindowSet) -> X ()
 withFocusedP f = withFocused $ windows . f
@@ -167,7 +165,7 @@ shiftHere :: (Ord a, Eq s, Eq i) => a -> StackSet i l a s sd -> StackSet i l a s
 shiftHere w s = shiftWin (currentTag s) w s
 
 shiftToScreen :: (Ord a, Eq s, Eq i) => s -> a -> StackSet i l a s sd -> StackSet i l a s sd
-shiftToScreen sid w s = case filter (\m -> sid /= screen m) ((current s):(visible s)) of
+shiftToScreen sid w s = case filter (\m -> sid /= screen m) (current s:visible s) of
                                 []      -> s
                                 (t:_)   -> shiftWin (tag . workspace $ t) w s
 
@@ -180,20 +178,19 @@ instance XPrompt TagPrompt where
 tagPrompt :: XPConfig -> (String -> X ()) -> X ()
 tagPrompt c f = do
   sc <- tagComplList
-  mkXPrompt TagPrompt c (mkComplFunFromList' sc) f
+  mkXPrompt TagPrompt c (mkComplFunFromList' c sc) f
 
 tagComplList :: X [String]
-tagComplList = gets (concat . map (integrate' . stack) . workspaces . windowset) >>=
-    mapM getTags >>=
-    return . nub . concat
+tagComplList = gets (concatMap (integrate' . stack) . workspaces . windowset)
+           >>= mapM getTags
+           <&> nub . concat
 
 
 tagDelPrompt :: XPConfig -> X ()
 tagDelPrompt c = do
   sc <- tagDelComplList
-  if (sc /= [])
-    then mkXPrompt TagPrompt c (mkComplFunFromList' sc) (\s -> withFocused (delTag s))
-    else return ()
+  when (sc /= []) $
+    mkXPrompt TagPrompt c (mkComplFunFromList' c sc) (withFocused . delTag)
 
 tagDelComplList :: X [String]
 tagDelComplList = gets windowset >>= maybe (return []) getTags . peek
