@@ -1,21 +1,23 @@
 -----------------------------------------------------------------------------
 -- |
 -- Module       : XMonad.Actions.WithAll
+-- Description  : Perform a given action on all or certain groups of windows.
 -- License      : BSD3-style (see LICENSE)
 -- Stability    : unstable
 -- Portability  : unportable
 --
--- Provides functions for performing a given action on all windows of
--- the current workspace.
+-- Provides functions for performing a given action on all or certain
+-- groups of windows on the current workspace.
 -----------------------------------------------------------------------------
 
 module XMonad.Actions.WithAll (
     -- * Usage
     -- $usage
     sinkAll, withAll,
-    withAll', killAll) where
+    withAll', killAll,
+    killOthers) where
 
-import Data.Foldable hiding (foldr)
+import XMonad.Prelude hiding (foldr)
 
 import XMonad
 import XMonad.StackSet
@@ -49,4 +51,8 @@ withAll f = withWindowSet $ \ws -> let all' = integrate' . stack . workspace . c
 
 -- | Kill all the windows on the current workspace.
 killAll :: X()
-killAll = withAll killWindow
\ No newline at end of file
+killAll = withAll killWindow
+
+-- | Kill all the unfocused windows on the current workspace.
+killOthers :: X ()
+killOthers = withUnfocused killWindow
