@@ -37,11 +37,11 @@ import qualified Data.Map as M
 -- If you prefer, an azertyKeys function is provided which you can use as so:
 --
 -- > import qualified Data.Map as M
--- > main = xmonad someConfig { keys = \c -> azertyKeys c <+> keys someConfig c }
+-- > main = xmonad someConfig { keys = \c -> azertyKeys c <> keys someConfig c }
 
-azertyConfig = def { keys = azertyKeys <+> keys def }
+azertyConfig = def { keys = azertyKeys <> keys def }
 
-belgianConfig = def { keys = belgianKeys <+> keys def }
+belgianConfig = def { keys = belgianKeys <> keys def }
 
 azertyKeys = azertyKeysTop [0x26,0xe9,0x22,0x27,0x28,0x2d,0xe8,0x5f,0xe7,0xe0]
 
