@@ -8,7 +8,7 @@
 -- License     :  BSD3-style (see LICENSE)
 --
 ------------------------------------------------------------------------
-module XMonad.Config.Droundy ( config, mytab ) where
+module XMonad.Config.Droundy {-# DEPRECATED "This module contains a personal configuration, to be removed from xmonad-contrib.  If you use this module, please copy the relevant parts to your configuration or obtain a copy of it on https://xmonad.org/configurations.html and include it as a local module." #-} ( config, mytab ) where
 
 import XMonad hiding (keys, config)
 import qualified XMonad (keys)
