@@ -42,11 +42,11 @@ import qualified Data.Map as M
 
 kdeConfig = desktopConfig
     { terminal = "konsole"
-    , keys     = kdeKeys <+> keys desktopConfig }
+    , keys     = kdeKeys <> keys desktopConfig }
 
 kde4Config = desktopConfig
     { terminal = "konsole"
-    , keys     = kde4Keys <+> keys desktopConfig }
+    , keys     = kde4Keys <> keys desktopConfig }
 
 kdeKeys XConfig{modMask = modm} = M.fromList
     [ ((modm,               xK_p), spawn "dcop kdesktop default popupExecuteCommand")
