@@ -38,7 +38,7 @@ import qualified Data.Map as M
 
 xfceConfig = desktopConfig
     { terminal = "xfce4-terminal"
-    , keys     = xfceKeys <+> keys desktopConfig }
+    , keys     = xfceKeys <> keys desktopConfig }
 
 xfceKeys XConfig{modMask = modm} = M.fromList
     [ ((modm,               xK_p), spawn "xfrun4")
