@@ -1,7 +1,7 @@
-{-# LANGUAGE DeriveDataTypeable #-}
 ----------------------------------------------------------------------------
 -- |
 -- Module      :  XMonad.Hooks.CurrentWorkspaceOnTop
+-- Description :  Ensure that windows on the current workspace are on top.
 -- Copyright   :  (c) Jan Vornberger 2009
 -- License     :  BSD3-style (see LICENSE)
 --
@@ -25,7 +25,7 @@ module XMonad.Hooks.CurrentWorkspaceOnTop (
 import XMonad
 import qualified XMonad.StackSet as S
 import qualified XMonad.Util.ExtensibleState as XS
-import Control.Monad(when)
+import XMonad.Prelude (unless, when)
 import qualified Data.Map as M
 
 -- $usage
@@ -40,7 +40,7 @@ import qualified Data.Map as M
 -- >  }
 --
 
-data CWOTState = CWOTS String deriving Typeable
+newtype CWOTState = CWOTS String
 
 instance ExtensionClass CWOTState where
   initialValue = CWOTS ""
@@ -55,15 +55,15 @@ currentWorkspaceOnTop = withDisplay $ \d -> do
         let s = S.current ws
             wsp = S.workspace s
             viewrect = screenRect $ S.screenDetail s
-            tmpStack = (S.stack wsp) >>= S.filter (`M.notMember` S.floating ws)
+            tmpStack = S.stack wsp >>= S.filter (`M.notMember` S.floating ws)
         (rs, ml') <- runLayout wsp { S.stack = tmpStack } viewrect
         updateLayout curTag ml'
         let this = S.view curTag ws
-            fltWins = filter (flip M.member (S.floating ws)) $ S.index this
-            wins = fltWins ++ (map fst rs)  -- order: first all floating windows, then the order the layout returned
+            fltWins = filter (`M.member` S.floating ws) $ S.index this
+            wins = fltWins ++ map fst rs  -- order: first all floating windows, then the order the layout returned
         -- end of reimplementation
 
-        when (not . null $ wins) $ do
+        unless (null wins) $ do
             io $ raiseWindow d (head wins)  -- raise first window of current workspace to the very top,
             io $ restackWindows d wins      -- then use restackWindows to let all other windows from the workspace follow
         XS.put(CWOTS curTag)
