@@ -85,9 +85,9 @@ import qualified XMonad.Util.ExtensibleState as XS
 -- | Add EWMH support for workspaces (virtual desktops) to the given
 -- 'XConfig'.  See above for an example.
 ewmh :: XConfig a -> XConfig a
-ewmh c = c { startupHook     = ewmhDesktopsStartup <+> startupHook c
-           , handleEventHook = ewmhDesktopsEventHook <+> handleEventHook c
-           , logHook         = ewmhDesktopsLogHook <+> logHook c }
+ewmh c = c { startupHook     = ewmhDesktopsStartup <> startupHook c
+           , handleEventHook = ewmhDesktopsEventHook <> handleEventHook c
+           , logHook         = ewmhDesktopsLogHook <> logHook c }
 
 
 -- $customization
@@ -293,6 +293,10 @@ instance ExtensionClass WindowDesktops where initialValue = WindowDesktops (M.si
 newtype ActiveWindow = ActiveWindow Window deriving Eq
 instance ExtensionClass ActiveWindow where initialValue = ActiveWindow (complement none)
 
+-- | Cached @_NET_DESKTOP_VIEWPORT@
+newtype MonitorTags = MonitorTags [WorkspaceId] deriving (Show,Eq)
+instance ExtensionClass MonitorTags where initialValue = MonitorTags []
+
 -- | Compare the given value against the value in the extensible state. Run the
 -- action if it has changed.
 whenChanged :: (Eq a, ExtensionClass a) => a -> X () -> X ()
@@ -337,6 +341,32 @@ ewmhDesktopsLogHook' EwmhDesktopsConfig{workspaceSort, workspaceRename} = withWi
     let activeWindow' = fromMaybe none (W.peek s)
     whenChanged (ActiveWindow activeWindow') $ setActiveWindow activeWindow'
 
+    -- Set desktop Viewport
+    let visibleScreens = W.current s : W.visible s
+        currentTags    = map (W.tag . W.workspace) visibleScreens
+    whenChanged (MonitorTags currentTags) $ mkViewPorts s (map W.tag ws)
+
+-- | Create the viewports from the current 'WindowSet' and a list of
+-- already sorted workspace IDs.
+mkViewPorts :: WindowSet -> [WorkspaceId] -> X ()
+mkViewPorts winset = setDesktopViewport . concat . mapMaybe (viewPorts M.!?)
+  where
+    foc = W.current winset
+    -- Hidden workspaces are mapped to the current screen's viewport.
+    viewPorts :: M.Map WorkspaceId [Position]
+    viewPorts = M.fromList $ map mkVisibleViewPort (foc : W.visible winset)
+                          ++ map (mkViewPort foc)  (W.hidden winset)
+
+    mkViewPort :: WindowScreen -> WindowSpace -> (WorkspaceId, [Position])
+    mkViewPort scr w = (W.tag w, mkPos scr)
+
+    mkVisibleViewPort :: WindowScreen -> (WorkspaceId, [Position])
+    mkVisibleViewPort x = mkViewPort x (W.workspace x)
+
+    mkPos :: WindowScreen -> [Position]
+    mkPos scr = [rect_x (rect scr), rect_y (rect scr)]
+      where rect = screenRect . W.screenDetail
+
 ewmhDesktopsEventHook' :: Event -> EwmhDesktopsConfig -> X All
 ewmhDesktopsEventHook'
         ClientMessageEvent{ev_window = w, ev_message_type = mt, ev_data = d}
@@ -376,8 +406,8 @@ ewmhDesktopsEventHook' _ _ = mempty
 
 -- | Add EWMH fullscreen functionality to the given config.
 ewmhFullscreen :: XConfig a -> XConfig a
-ewmhFullscreen c = c { startupHook     = startupHook c <+> fullscreenStartup
-                     , handleEventHook = handleEventHook c <+> fullscreenEventHook }
+ewmhFullscreen c = c { startupHook     = startupHook c <> fullscreenStartup
+                     , handleEventHook = handleEventHook c <> fullscreenEventHook }
 
 -- | Advertises EWMH fullscreen support to the X server.
 {-# DEPRECATED fullscreenStartup "Use ewmhFullscreen instead." #-}
@@ -461,6 +491,12 @@ setActiveWindow w = withDisplay $ \dpy -> do
     a <- getAtom "_NET_ACTIVE_WINDOW"
     io $ changeProperty32 dpy r a wINDOW propModeReplace [fromIntegral w]
 
+setDesktopViewport :: [Position] -> X ()
+setDesktopViewport positions = withDisplay $ \dpy -> do
+    r <- asks theRoot
+    a <- io $ internAtom dpy "_NET_DESKTOP_VIEWPORT" True
+    io $ changeProperty32 dpy r a cARDINAL propModeReplace (map fi positions)
+
 setSupported :: X ()
 setSupported = withDisplay $ \dpy -> do
     r <- asks theRoot
@@ -475,6 +511,7 @@ setSupported = withDisplay $ \dpy -> do
                          ,"_NET_ACTIVE_WINDOW"
                          ,"_NET_WM_DESKTOP"
                          ,"_NET_WM_STRUT"
+                         ,"_NET_DESKTOP_VIEWPORT"
                          ]
     io $ changeProperty32 dpy r a aTOM propModeReplace (fmap fromIntegral supp)
 
