@@ -1,6 +1,7 @@
 -----------------------------------------------------------------------------
 -- |
 -- Module       : XMonad.Hooks.ICCCMFocus
+-- Description  : Deprecated.
 -- License      : BSD
 --
 -- Maintainer   : Tony Morris <haskell@tmorris.net>
@@ -38,5 +39,4 @@ takeFocusX _w = return ()
 takeTopFocus ::
   X ()
 takeTopFocus =
-  (withWindowSet $ maybe (setFocusX =<< asks theRoot) takeFocusX . W.peek) >> setWMName "LG3D"
-
+  withWindowSet (maybe (setFocusX =<< asks theRoot) takeFocusX . W.peek) >> setWMName "LG3D"
