@@ -32,9 +32,9 @@
 -- > f :: a -> b -> Bool
 -- >
 -- > -- a new helper
--- > q ***? x = fmap (\a -> f a x) q
+-- > q ***? x = fmap (\a -> f a x) q   -- or: (\b -> f x b)
 -- > -- or
--- > q ***? x = fmap (`f` x) q
+-- > q ***? x = fmap (`f` x) q         -- or: (x `f`)
 --
 -- Any existing operator can be "lifted" in the same way:
 --
@@ -49,6 +49,7 @@ module XMonad.Hooks.ManageHelpers (
     isInProperty,
     isKDETrayWindow,
     isFullscreen,
+    isMinimized,
     isDialog,
     pid,
     transientTo,
@@ -109,17 +110,17 @@ infixr 0 -?>, -->>, -?>>
 (/=?) :: (Eq a, Functor m) => m a -> a -> m Bool
 q /=? x = fmap (/= x) q
 
--- | q ^? x. if the result of q 'isPrefixOf' x, return True
+-- | q ^? x. if the result of @x `isPrefixOf` q@, return True
 (^?) :: (Eq a, Functor m) => m [a] -> [a] -> m Bool
-q ^? x = fmap (`isPrefixOf` x) q
+q ^? x = fmap (x `isPrefixOf`) q
 
--- | q ~? x. if the result of q 'isSuffixOf' x, return True
+-- | q ~? x. if the result of @x `isInfixOf` q@, return True
 (~?) :: (Eq a, Functor m) => m [a] -> [a] -> m Bool
-q ~? x = fmap (`isInfixOf` x) q
+q ~? x = fmap (x `isInfixOf`) q
 
--- | q $? x. if the result of q 'isSuffixOf' x, return True
+-- | q $? x. if the result of @x `isSuffixOf` q@, return True
 ($?) :: (Eq a, Functor m) => m [a] -> [a] -> m Bool
-q $? x = fmap (`isSuffixOf` x) q
+q $? x = fmap (x `isSuffixOf`) q
 
 -- | q <==? x. if the result of q equals x, return True grouped with q
 (<==?) :: (Eq a, Functor m) => m a -> a -> m (Match a)
@@ -183,6 +184,11 @@ isInProperty p v = ask >>= \w -> liftX $ do
 isFullscreen :: Query Bool
 isFullscreen = isInProperty "_NET_WM_STATE" "_NET_WM_STATE_FULLSCREEN"
 
+-- | A predicate to check whether a window is hidden (minimized).
+-- See also "XMonad.Actions.Minimize".
+isMinimized :: Query Bool
+isMinimized = isInProperty "_NET_WM_STATE" "_NET_WM_STATE_HIDDEN"
+
 -- | A predicate to check whether a window is a dialog.
 isDialog :: Query Bool
 isDialog = isInProperty "_NET_WM_WINDOW_TYPE" "_NET_WM_WINDOW_TYPE_DIALOG"
