@@ -1,6 +1,7 @@
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  XMonad.Hooks.RestoreMinimized
+-- Description :  Deprecated: Use XMonad.Hooks.Minimize.
 -- Copyright   :  (c) Jan Vornberger 2009
 -- License     :  BSD3-style (see LICENSE)
 --
@@ -22,7 +23,7 @@ module XMonad.Hooks.RestoreMinimized
     , restoreMinimizedEventHook
     ) where
 
-import Data.Monoid
+import XMonad.Prelude
 
 import XMonad
 
