@@ -1,7 +1,8 @@
-{-# LANGUAGE FlexibleInstances, MultiParamTypeClasses, TypeSynonymInstances, FlexibleContexts #-}
+{-# LANGUAGE FlexibleInstances, MultiParamTypeClasses, FlexibleContexts #-}
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  XMonad.Layout.AutoMaster
+-- Description :  Change size of the stack area depending on the number of its windows.
 -- Copyright   :  (c) 2009 Ilya Portnov
 -- License     :  BSD3-style (see LICENSE)
 --
@@ -20,11 +21,13 @@ module XMonad.Layout.AutoMaster (
                              -- $usage
                              autoMaster, AutoMaster
                             ) where
-import Control.Monad
-
 import XMonad
-import qualified XMonad.StackSet as W
 import XMonad.Layout.LayoutModifier
+import XMonad.Prelude
+import qualified XMonad.StackSet as W
+
+import Control.Arrow (first)
+
 
 -- $usage
 -- This module defines layout modifier named autoMaster. It separates
@@ -57,7 +60,7 @@ autoMess :: AutoMaster a -> SomeMessage -> Maybe (AutoMaster a)
 autoMess (AutoMaster k bias delta) m = msum [fmap resize (fromMessage m),
                                              fmap incmastern (fromMessage m)]
     where incmastern (IncMasterN d) = AutoMaster (max 1 (k+d)) bias delta
-          resize Expand = AutoMaster k (min ( 0.4)  $ bias+delta) delta
+          resize Expand = AutoMaster k (min 0.4  $ bias+delta) delta
           resize Shrink = AutoMaster k (max (-0.4)  $ bias-delta) delta
 
 -- | Main layout function
@@ -73,33 +76,33 @@ autoLayout k bias wksp rect = do
     let n = length ws
     if null ws then
         runLayout wksp rect
-        else do
-          if (n<=k) then
-              return ((divideRow rect ws),Nothing)
+        else
+          if n<=k then
+              return (divideRow rect ws,Nothing)
               else do
               let master = take k ws
-              let filtStack = stack >>= W.filter (\w -> not (w `elem` master))
+              let filtStack = stack >>= W.filter (`notElem` master)
               wrs <- runLayout (wksp {W.stack = filtStack}) (slaveRect rect n bias)
-              return ((divideRow (masterRect rect n bias) master) ++ (fst wrs),
-                      snd wrs)
+              return $ first (divideRow (masterRect rect n bias) master ++)
+                             wrs
 
 -- | Calculates height of master area, depending on number of windows.
 masterHeight :: Int -> Float -> Float
-masterHeight n bias = (calcHeight n) + bias
+masterHeight n bias = calcHeight n + bias
     where calcHeight :: Int -> Float
           calcHeight 1 = 1.0
-          calcHeight m = if (m<9) then (43/45) - (fromIntegral m)*(7/90) else (1/3)
+          calcHeight m = if m<9 then (43/45) - fromIntegral m*(7/90) else 1/3
 
 -- | Rectangle for master area
 masterRect :: Rectangle -> Int -> Float -> Rectangle
 masterRect (Rectangle sx sy sw sh) n bias = Rectangle sx sy sw h
-    where h = round $ (fromIntegral sh)*(masterHeight n bias)
+    where h = round $ fromIntegral sh*masterHeight n bias
 
 -- | Rectangle for slave area
 slaveRect :: Rectangle -> Int -> Float -> Rectangle
 slaveRect (Rectangle sx sy sw sh) n bias = Rectangle sx (sy+mh) sw h
-    where mh = round $ (fromIntegral sh)*(masterHeight n bias)
-          h  = round $ (fromIntegral sh)*(1-masterHeight n bias)
+    where mh = round $ fromIntegral sh*masterHeight n bias
+          h  = round $ fromIntegral sh*(1-masterHeight n bias)
 
 -- | Divide rectangle between windows
 divideRow :: Rectangle -> [a] -> [(a, Rectangle)]
@@ -120,4 +123,3 @@ autoMaster :: LayoutClass l a =>
               l a ->
               ModifiedLayout AutoMaster l a
 autoMaster nmaster delta = ModifiedLayout (AutoMaster nmaster 0 delta)
-
