@@ -1,6 +1,7 @@
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  XMonad.Layout.DecorationMadness
+-- Description :  A collection of decorated layouts.
 -- Copyright   :  (c) 2007 Andrea Rossato
 -- License     :  BSD-style (see xmonad/LICENSE)
 --
@@ -82,7 +83,7 @@ module XMonad.Layout.DecorationMadness
     , floatDwmStyle
     , floatSimpleTabbed
     , floatTabbed
-    , def, defaultTheme, shrinkText
+    , def, shrinkText
     ) where
 
 import XMonad
