@@ -1,8 +1,9 @@
-{-# LANGUAGE DeriveDataTypeable, FlexibleInstances, MultiParamTypeClasses, PatternGuards, TypeSynonymInstances #-}
+{-# LANGUAGE FlexibleInstances, MultiParamTypeClasses, PatternGuards #-}
 
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  XMonad.Layout.DragPane
+-- Description :  Split the screen either horizontally or vertically and show two windows.
 -- Copyright   :  (c) Spencer Janssen <spencerjanssen@gmail.com>
 --                    David Roundy <droundy@darcs.net>,
 --                    Andrea Rossato <andrea.rossato@unibz.it>
@@ -54,7 +55,7 @@ handleColor :: String
 handleColor = "#000000"
 
 dragPane :: DragType -> Double -> Double -> DragPane a
-dragPane t x y = DragPane (I Nothing) t x y
+dragPane = DragPane (I Nothing)
 
 data DragPane a =
     DragPane (Invisible Maybe (Window,Rectangle,Int)) DragType Double Double
@@ -67,7 +68,7 @@ instance LayoutClass DragPane a where
     doLayout d@(DragPane _ Horizontal _ _) = doLay mirrorRect d
     handleMessage = handleMess
 
-data SetFrac = SetFrac Int Double deriving ( Show, Read, Eq, Typeable )
+data SetFrac = SetFrac Int Double deriving ( Show, Read, Eq)
 instance Message SetFrac
 
 handleMess :: DragPane a -> SomeMessage -> X (Maybe (DragPane a))
@@ -81,18 +82,18 @@ handleMess d@(DragPane mb@(I (Just (win,_,ident))) ty delta split) x
     -- layout specific messages
     | Just Shrink <- fromMessage x = return $ Just (DragPane mb ty delta (split - delta))
     | Just Expand <- fromMessage x = return $ Just (DragPane mb ty delta (split + delta))
-    | Just (SetFrac ident' frac) <- fromMessage x, ident' == ident = do
+    | Just (SetFrac ident' frac) <- fromMessage x, ident' == ident =
                                      return $ Just (DragPane mb ty delta frac)
 handleMess _ _ = return Nothing
 
 handleEvent :: DragPane a -> Event -> X ()
 handleEvent (DragPane (I (Just (win,r,ident))) ty _ _)
-            (ButtonEvent {ev_window = thisw, ev_subwindow = thisbw, ev_event_type = t })
-    | t == buttonPress && thisw == win || thisbw == win  = do
+            ButtonEvent{ev_window = thisw, ev_subwindow = thisbw, ev_event_type = t }
+    | t == buttonPress && thisw == win || thisbw == win  =
   mouseDrag (\ex ey -> do
              let frac = case ty of
-                        Vertical   -> (fromIntegral ex - (fromIntegral $ rect_x r))/(fromIntegral $ rect_width  r)
-                        Horizontal -> (fromIntegral ey - (fromIntegral $ rect_x r))/(fromIntegral $ rect_width r)
+                        Vertical   -> (fromIntegral ex - fromIntegral (rect_x r))/fromIntegral (rect_width  r)
+                        Horizontal -> (fromIntegral ey - fromIntegral (rect_x r))/fromIntegral (rect_width r)
              sendMessage (SetFrac ident frac))
             (return ())
 handleEvent _ _  = return ()
@@ -121,7 +122,7 @@ doLay mirror (DragPane mw ty delta split) r s = do
                     return (wrs, Just $ DragPane (I $ Just (w',r',ident)) ty delta split)
             I Nothing -> do
                     w <- newDragWin handr
-                    i <- io $ newUnique
+                    i <- io newUnique
                     return (wrs, Just $ DragPane (I $ Just (w,r',hashUnique i)) ty delta split)
      else return (wrs, Nothing)
 
