@@ -4,6 +4,7 @@
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  XMonad.Layout.Groups.Wmii
+-- Description :  A wmii-like layout algorithm.
 -- Copyright   :  Quentin Moser <moserq@gmail.com>
 -- License     :  BSD-style (see LICENSE)
 --
@@ -31,10 +32,9 @@ module XMonad.Layout.Groups.Wmii ( -- * Usage
                                    -- * Useful re-exports
                                  , shrinkText
                                  , def
-                                 , defaultTheme
                                  , module XMonad.Layout.Groups.Helpers ) where
 
-import XMonad hiding ((|||))
+import XMonad
 
 import qualified XMonad.Layout.Groups as G
 import XMonad.Layout.Groups.Examples
@@ -43,7 +43,6 @@ import XMonad.Layout.Groups.Helpers
 import XMonad.Layout.Tabbed
 import XMonad.Layout.Named
 import XMonad.Layout.Renamed
-import XMonad.Layout.LayoutCombinators
 import XMonad.Layout.MessageControl
 import XMonad.Layout.Simplest
 
@@ -92,7 +91,7 @@ import XMonad.Layout.Simplest
 -- | A layout inspired by wmii
 wmii s t = G.group innerLayout zoomRowG
     where column = named "Column" $ Tall 0 (3/100) (1/2)
-          tabs = named "Tabs" $ Simplest
+          tabs = named "Tabs" Simplest
           innerLayout = renamed [CutWordsLeft 3]
                         $ addTabs s t
                         $ ignore NextLayout
@@ -131,4 +130,3 @@ groupToTabbedLayout = sendMessage $ escape $ JumpToLayout "Tabs"
 -- | Switch the focused group to the \"column\" layout.
 groupToVerticalLayout :: X ()
 groupToVerticalLayout = sendMessage $ escape $ JumpToLayout "Column"
-
