@@ -1,8 +1,9 @@
-{-# LANGUAGE DeriveDataTypeable, FlexibleContexts, MultiParamTypeClasses, TypeSynonymInstances, PatternGuards #-}
+{-# LANGUAGE FlexibleContexts, MultiParamTypeClasses, TypeSynonymInstances, PatternGuards #-}
 
 ----------------------------------------------------------------------------
 -- |
 -- Module      :  XMonad.Layout.Hidden
+-- Description :  Hide windows from layouts.
 -- Copyright   :  (c) Peter Jones 2015
 -- License     :  BSD3-style (see LICENSE)
 --
@@ -20,11 +21,13 @@
 module XMonad.Layout.Hidden
        ( -- * Usage
          -- $usage
-         HiddenMsg (..)
+         HiddenWindows
+       , HiddenMsg (..)
        , hiddenWindows
        , hideWindow
        , popOldestHiddenWindow
        , popNewestHiddenWindow
+       , popHiddenWindow
        ) where
 
 --------------------------------------------------------------------------------
@@ -58,24 +61,26 @@ import qualified XMonad.StackSet as W
 -- "XMonad.Doc.Extending#Editing_key_bindings".
 
 --------------------------------------------------------------------------------
-data HiddenWindows a = HiddenWindows [Window] deriving (Show, Read)
+newtype HiddenWindows a = HiddenWindows [Window] deriving (Show, Read)
 
 --------------------------------------------------------------------------------
 -- | Messages for the @HiddenWindows@ layout modifier.
-data HiddenMsg = HideWindow Window       -- ^ Hide a window.
-               | PopNewestHiddenWindow   -- ^ Restore window (FILO).
-               | PopOldestHiddenWindow   -- ^ Restore window (FIFO).
-               deriving (Typeable, Eq)
+data HiddenMsg = HideWindow Window                -- ^ Hide a window.
+               | PopNewestHiddenWindow            -- ^ Restore window (FILO).
+               | PopOldestHiddenWindow            -- ^ Restore window (FIFO).
+               | PopSpecificHiddenWindow Window   -- ^ Restore specific window.
+               deriving (Eq)
 
 instance Message HiddenMsg
 
 --------------------------------------------------------------------------------
 instance LayoutModifier HiddenWindows Window where
   handleMess h@(HiddenWindows hidden) mess
-    | Just (HideWindow win)        <- fromMessage mess = hideWindowMsg h win
-    | Just (PopNewestHiddenWindow) <- fromMessage mess = popNewestMsg h
-    | Just (PopOldestHiddenWindow) <- fromMessage mess = popOldestMsg h
-    | Just ReleaseResources        <- fromMessage mess = doUnhook
+    | Just (HideWindow win)              <- fromMessage mess = hideWindowMsg h win
+    | Just PopNewestHiddenWindow         <- fromMessage mess = popNewestMsg h
+    | Just PopOldestHiddenWindow         <- fromMessage mess = popOldestMsg h
+    | Just (PopSpecificHiddenWindow win) <- fromMessage mess = popSpecificMsg win h
+    | Just ReleaseResources              <- fromMessage mess = doUnhook
     | otherwise                                        = return Nothing
     where doUnhook = do mapM_ restoreWindow hidden
                         return Nothing
@@ -107,6 +112,9 @@ popOldestHiddenWindow = sendMessage PopOldestHiddenWindow
 popNewestHiddenWindow :: X ()
 popNewestHiddenWindow = sendMessage PopNewestHiddenWindow
 
+popHiddenWindow :: Window -> X ()
+popHiddenWindow = sendMessage . PopSpecificHiddenWindow
+
 --------------------------------------------------------------------------------
 hideWindowMsg :: HiddenWindows a -> Window -> X (Maybe (HiddenWindows a))
 hideWindowMsg (HiddenWindows hidden) win = do
@@ -128,7 +136,16 @@ popOldestMsg (HiddenWindows (win:rest)) = do
   restoreWindow win
   return . Just . HiddenWindows $ rest
 
+--------------------------------------------------------------------------------
+popSpecificMsg :: Window -> HiddenWindows a -> X (Maybe (HiddenWindows a))
+popSpecificMsg _   (HiddenWindows []) = return Nothing
+popSpecificMsg win (HiddenWindows hiddenWins) = if win `elem` hiddenWins
+  then do
+    restoreWindow win
+    return . Just . HiddenWindows $ filter (/= win) hiddenWins
+  else
+    return . Just . HiddenWindows $ hiddenWins
+
 --------------------------------------------------------------------------------
 restoreWindow :: Window -> X ()
-restoreWindow win =
-  modify (\s -> s { windowset = W.insertUp win $ windowset s })
+restoreWindow = windows . W.insertUp
