@@ -1,4 +1,3 @@
-{-# LANGUAGE DeriveDataTypeable    #-}
 {-# LANGUAGE FlexibleContexts      #-}
 {-# LANGUAGE FlexibleInstances     #-}
 {-# LANGUAGE MultiParamTypeClasses #-}
@@ -10,6 +9,7 @@
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  XMonad.Layout.LayoutBuilder
+-- Description :  Send a number of windows to one rectangle and the rest to another.
 --
 -- Copyright   :  (c) 2009 Anders Engstrom <ankaan@gmail.com>,
 --                    2011 Ilya Portnov <portnov84@rambler.ru>,
@@ -57,11 +57,8 @@ module XMonad.Layout.LayoutBuilder (
   LayoutN,
 ) where
 
---------------------------------------------------------------------------------
-import Control.Applicative ((<|>))
-import Control.Monad (foldM)
-import Data.Maybe
 import XMonad
+import XMonad.Prelude (foldM, (<|>), isJust, fromMaybe, isNothing, listToMaybe)
 import qualified XMonad.StackSet as W
 import XMonad.Util.WindowProperties
 
@@ -225,7 +222,7 @@ layoutAll box sub = LayoutB Nothing Nothing (LimitR (0,1)) box Nothing sub Nothi
 
 --------------------------------------------------------------------------------
 -- | Change the number of windows handled by the focused layout.
-data IncLayoutN = IncLayoutN Int deriving Typeable
+newtype IncLayoutN = IncLayoutN Int
 instance Message IncLayoutN
 
 --------------------------------------------------------------------------------
@@ -259,7 +256,7 @@ relBox x y w h = SubBox (Rel x) (Rel y) (Rel w) (Rel h)
 
 --------------------------------------------------------------------------------
 instance ( LayoutClass l1 a, LayoutClass l2 a
-         , Read a, Show a, Show p, Eq a, Typeable a, Predicate p a
+         , Read a, Show a, Show p, Typeable p, Eq a, Typeable a, Predicate p a
          ) => LayoutClass (LayoutB l1 l2 p) a where
 
     -- | Update window locations.
@@ -370,7 +367,7 @@ sendFocus l@(LayoutB subFocus _ _ _ _ _ _) m = do
 -- | Check to see if the given window is currently focused.
 isFocus :: (Show a) => Maybe a -> X Bool
 isFocus Nothing = return False
-isFocus (Just w) = do ms <- (W.stack . W.workspace . W.current) `fmap` gets windowset
+isFocus (Just w) = do ms <- W.stack . W.workspace . W.current <$> gets windowset
                       return $ maybe False (\s -> show w == show (W.focus s)) ms
 
 --------------------------------------------------------------------------------
