@@ -1,6 +1,7 @@
 {-# LANGUAGE FlexibleInstances, MultiParamTypeClasses #-}
 {-# LANGUAGE ParallelListComp, PatternGuards #-}
 {-# LANGUAGE TupleSections #-}
+{-# LANGUAGE LambdaCase #-}
 -----------------------------------------------------------------------------
 -- |
 -- Module       : XMonad.Layout.LayoutHints
@@ -32,8 +33,8 @@ import XMonad(LayoutClass(runLayout), mkAdjust, Window,
               Dimension, Position, Rectangle(Rectangle), D,
               X, refresh, Event(..), propertyNotify, wM_NORMAL_HINTS,
               (<&&>), io, applySizeHints, whenX, isClient, withDisplay,
-              getWindowAttributes, getWMNormalHints, WindowAttributes(..))
-import XMonad.Prelude (All (..), fromJust, join, maximumBy, on, sortBy)
+              getWMNormalHints, WindowAttributes(..))
+import XMonad.Prelude
 import qualified XMonad.StackSet as W
 
 import XMonad.Layout.Decoration(isInStack)
@@ -72,7 +73,7 @@ import qualified Data.Set as Set
 -- To make XMonad reflect changes in window hints immediately, add
 -- 'hintsEventHook' to your 'handleEventHook'.
 --
--- > myHandleEventHook = hintsEventHook <+> ...
+-- > myHandleEventHook = hintsEventHook <> ...
 -- >
 -- > main = xmonad def { handleEventHook = myHandleEventHook
 -- >                   , ... }
@@ -164,7 +165,7 @@ applyHints s root (((w,lrect@(Rectangle a b c d)),adj):xs) =
                     $ if isInStack s w then Rectangle a b c' d' else lrect
 
             ds = (fromIntegral c - fromIntegral c',fromIntegral d - fromIntegral d')
-            growOther' r = growOther ds lrect (freeDirs root lrect) r
+            growOther' = growOther ds lrect (freeDirs root lrect)
             mapSnd f = map (first $ second f)
             next = applyHints s root $ mapSnd growOther' xs
         in (w,redr):next
@@ -264,8 +265,9 @@ hintsEventHook _ = return (All True)
 
 -- | True if the window's current size does not satisfy its size hints.
 hintsMismatch :: Window -> X Bool
-hintsMismatch w = withDisplay $ \d -> io $ do
-    wa <- getWindowAttributes d w
-    sh <- getWMNormalHints d w
-    let dim = (fromIntegral $ wa_width wa, fromIntegral $ wa_height wa)
-    return $ dim /= applySizeHints 0 sh dim
+hintsMismatch w = safeGetWindowAttributes w >>= \case
+    Nothing -> pure False
+    Just wa -> do
+        sh <- withDisplay $ \d -> io (getWMNormalHints d w)
+        let dim = (fromIntegral $ wa_width wa, fromIntegral $ wa_height wa)
+        return $ dim /= applySizeHints 0 sh dim
