@@ -1,4 +1,5 @@
 {-# LANGUAGE FlexibleContexts, FlexibleInstances, MultiParamTypeClasses #-}
+{-# LANGUAGE ViewPatterns #-}
 
 -----------------------------------------------------------------------------
 -- |
@@ -22,6 +23,7 @@ module XMonad.Layout.LayoutScreens (
                                    ) where
 
 import XMonad
+import XMonad.Prelude
 import qualified XMonad.StackSet as W
 
 -- $usage
@@ -60,12 +62,14 @@ import qualified XMonad.StackSet as W
 -- | Modify all screens.
 layoutScreens :: LayoutClass l Int => Int -> l Int -> X ()
 layoutScreens nscr _ | nscr < 1 = trace $ "Can't layoutScreens with only " ++ show nscr ++ " screens."
-layoutScreens nscr l =
-    do rtrect <- asks theRoot >>= getWindowRectangle
+layoutScreens nscr l = asks theRoot >>= \w -> withDisplay $ \d ->
+  withWindowAttributes d w $ \attrs ->
+    do let rtrect = windowRectangle attrs
        (wss, _) <- runLayout (W.Workspace "" l (Just $ W.Stack { W.focus=1, W.up=[],W.down=[1..nscr-1] })) rtrect
        windows $ \ws@W.StackSet{ W.current = v, W.visible = vs, W.hidden = hs } ->
-           let (x:xs, ys) = splitAt nscr $ map W.workspace (v:vs) ++ hs
-               s:ss = map snd wss
+           let x = W.workspace v
+               (xs, ys) = splitAt (nscr - 1) $ map W.workspace vs ++ hs
+               (notEmpty -> s :| ss) = map snd wss
            in  ws { W.current = W.Screen x 0 (SD s)
                   , W.visible = zipWith3 W.Screen xs [1 ..] $ map SD ss
                   , W.hidden  = ys }
@@ -77,18 +81,17 @@ layoutSplitScreen nscr l =
     do rect <- gets $ screenRect . W.screenDetail . W.current . windowset
        (wss, _) <- runLayout (W.Workspace "" l (Just $ W.Stack { W.focus=1, W.up=[],W.down=[1..nscr-1] })) rect
        windows $ \ws@W.StackSet{ W.current = c, W.visible = vs, W.hidden = hs } ->
-           let (x:xs, ys) = splitAt nscr $ W.workspace c : hs
-               s:ss = map snd wss
+           let x = W.workspace c
+               (xs, ys) = splitAt (nscr - 1) hs
+               (notEmpty -> s :| ss) = map snd wss
            in  ws { W.current = W.Screen x (W.screen c) (SD s)
                   , W.visible = zipWith3 W.Screen xs [(W.screen c+1) ..] (map SD ss) ++
                                 map (\v -> if W.screen v>W.screen c then v{W.screen = W.screen v + fromIntegral (nscr-1)} else v) vs
                   , W.hidden  = ys }
 
-getWindowRectangle :: Window -> X Rectangle
-getWindowRectangle w = withDisplay $ \d ->
-    do a <- io $ getWindowAttributes d w
-       return $ Rectangle (fromIntegral $ wa_x a)     (fromIntegral $ wa_y a)
-                          (fromIntegral $ wa_width a) (fromIntegral $ wa_height a)
+windowRectangle :: WindowAttributes -> Rectangle
+windowRectangle a = Rectangle (fromIntegral $ wa_x a)     (fromIntegral $ wa_y a)
+                              (fromIntegral $ wa_width a) (fromIntegral $ wa_height a)
 
 newtype FixedLayout a = FixedLayout [Rectangle] deriving (Read,Show)
 
