@@ -1,8 +1,9 @@
-{-# LANGUAGE FlexibleInstances, MultiParamTypeClasses, TypeSynonymInstances, FlexibleContexts, PatternGuards #-}
+{-# LANGUAGE FlexibleInstances, MultiParamTypeClasses, FlexibleContexts, PatternGuards #-}
 
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  XMonad.Layout.Master
+-- Description :  Layout modfier that adds a master window to another layout.
 -- Copyright   :  (c) Ismael Carnales, Lukas Mai
 -- License     :  BSD-style (see LICENSE)
 --
@@ -26,7 +27,8 @@ module XMonad.Layout.Master (
 import XMonad
 import qualified XMonad.StackSet as S
 import XMonad.Layout.LayoutModifier
-import Control.Monad
+
+import Control.Arrow (first)
 
 -- $usage
 -- You can use this module with the following in your @~\/.xmonad\/xmonad.hs@:
@@ -72,7 +74,7 @@ mastered :: (LayoutClass l a) =>
     -> Rational -- ^ @frac@, what portion of the screen to use for the master window
     -> l a      -- ^ the layout to be modified
     -> ModifiedLayout AddMaster l a
-mastered delta frac = multimastered 1 delta frac
+mastered = multimastered 1
 
 instance LayoutModifier AddMaster Window where
     modifyLayout (AddMaster k delta frac) = applyMaster False k delta frac
@@ -85,12 +87,12 @@ instance LayoutModifier AddMaster Window where
 
     pureMess _ _ = Nothing
 
-data FixMaster a = FixMaster (AddMaster a) deriving (Show, Read)
+newtype FixMaster a = FixMaster (AddMaster a) deriving (Show, Read)
 
 instance LayoutModifier FixMaster Window where
     modifyLayout (FixMaster (AddMaster k d f)) = applyMaster True k d f
     modifierDescription (FixMaster a) = "Fix" ++ modifierDescription a
-    pureMess (FixMaster a) m = liftM FixMaster (pureMess a m)
+    pureMess (FixMaster a) m = fmap FixMaster (pureMess a m)
 
 fixMastered :: (LayoutClass l a) =>
        Rational -- ^ @delta@, the ratio of the screen to resize by
@@ -111,17 +113,17 @@ applyMaster :: (LayoutClass l Window) =>
                -> X ([(Window, Rectangle)], Maybe (l Window))
 applyMaster f k _ frac wksp rect = do
     let st= S.stack wksp
-    let ws = S.integrate' $ st
+    let ws = S.integrate' st
     let n = length ws + fromEnum f
-    if n > 1 then do
-        if(n<=k) then
-             return ((divideCol rect ws), Nothing)
+    if n > 1 then
+        if n<=k then
+             return (divideCol rect ws, Nothing)
              else do
              let m = take k ws
              let (mr, sr) = splitHorizontallyBy frac rect
-             let nst = st>>= S.filter (\w -> not (w `elem` m))
+             let nst = st>>= S.filter (`notElem` m)
              wrs <- runLayout (wksp {S.stack = nst}) sr
-             return ((divideCol mr m) ++ (fst wrs), snd wrs)
+             return (first (divideCol mr m ++) wrs)
         else runLayout wksp rect
 
 -- | Shift rectangle down
@@ -135,4 +137,3 @@ divideCol (Rectangle x y w h) ws = zip ws rects
           oneH = fromIntegral h `div` n
           oneRect = Rectangle x y w (fromIntegral oneH)
           rects = take n $ iterate (shiftD (fromIntegral oneH)) oneRect
-
