@@ -1,8 +1,9 @@
-{-# LANGUAGE DeriveDataTypeable, FlexibleContexts, FlexibleInstances, MultiParamTypeClasses, TypeSynonymInstances #-}
+{-# LANGUAGE FlexibleContexts, FlexibleInstances, MultiParamTypeClasses #-}
 
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  XMonad.Layout.Maximize
+-- Description :  Temporarily yank the focused window out of the layout to mostly fill the screen.
 -- Copyright   :  (c) 2007 James Webb
 -- License     :  BSD3-style (see LICENSE)
 --
@@ -27,7 +28,7 @@ module XMonad.Layout.Maximize (
 import XMonad
 import qualified XMonad.StackSet as S
 import XMonad.Layout.LayoutModifier
-import Data.List ( partition )
+import XMonad.Prelude ( partition )
 
 -- $usage
 -- You can use this module with the following in your @~\/.xmonad\/xmonad.hs@:
@@ -67,7 +68,7 @@ maximize = ModifiedLayout $ Maximize 25 Nothing
 maximizeWithPadding :: LayoutClass l Window => Dimension -> l Window -> ModifiedLayout Maximize l Window
 maximizeWithPadding padding = ModifiedLayout $ Maximize padding Nothing
 
-data MaximizeRestore = MaximizeRestore Window deriving ( Typeable, Eq )
+newtype MaximizeRestore = MaximizeRestore Window deriving ( Eq )
 instance Message MaximizeRestore
 maximizeRestore :: Window -> MaximizeRestore
 maximizeRestore = MaximizeRestore
@@ -91,7 +92,7 @@ instance LayoutModifier Maximize Window where
 
     pureMess (Maximize padding mw) m = case fromMessage m of
         Just (MaximizeRestore w) -> case mw of
-            Just w' -> if (w == w')
+            Just w' -> if w == w'
                         then Just $ Maximize padding Nothing   -- restore window
                         else Just $ Maximize padding $ Just w  -- maximize different window
             Nothing -> Just $ Maximize padding $ Just w        -- maximize window
