@@ -111,7 +111,7 @@ instance LayoutClass Mosaic a where
         nextIx (ov,ix,mix)
                 | mix <= 0 || ov = fromIntegral $ nls `div` 2
                 | otherwise = max 0 $ (*fi (pred nls)) $ min 1 $ ix / fi mix
-        rect = rects !! maybe (nls `div` 2) round (nextIx <$> state)
+        rect = rects !! maybe (nls `div` 2) (round . nextIx) state
         state' = fmap (\x@(ov,_,_) -> (ov,nextIx x,pred nls)) state
                     `mplus` Just (True,fromIntegral nls / 2,pred nls)
         ss' = maybe ss (const ss `either` const ssExt) $ zipRemain ss ssExt
@@ -190,14 +190,13 @@ instance Functor Tree where
    fmap f (Branch l r) = Branch (fmap f l) (fmap f r)
    fmap _ Empty = Empty
 
+instance Semigroup (Tree a) where
+    Empty <> x = x
+    x <> Empty = x
+    x <> y = Branch x y
+
 instance Monoid (Tree a) where
     mempty = Empty
-    mappend Empty x = x
-    mappend x Empty = x
-    mappend x y = Branch x y
-
-instance Semigroup (Tree a) where
-    (<>) = mappend
 
 makeTree ::  (Num a1, Ord a1) => (a -> a1) -> [a] -> Tree a
 makeTree _ [] = Empty
