@@ -1,9 +1,11 @@
 {-# LANGUAGE FlexibleContexts, FlexibleInstances, MultiParamTypeClasses #-}
-{-# LANGUAGE TypeSynonymInstances, PatternGuards, DeriveDataTypeable #-}
+{-# LANGUAGE PatternGuards #-}
+{-# OPTIONS_GHC -Wno-dodgy-imports #-} -- singleton in Data.List since base 4.15
 
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  XMonad.Layout.NoBorders
+-- Description :  Make a given layout display without borders.
 -- Copyright   :  (c) --    David Roundy <droundy@darcs.net>
 --                    2018  Yclept Nemo
 -- License     :  BSD3-style (see LICENSE)
@@ -34,16 +36,12 @@ module XMonad.Layout.NoBorders ( -- * Usage
                                ) where
 
 import           XMonad
+import           XMonad.Prelude hiding (singleton)
 import           XMonad.Layout.LayoutModifier
 import qualified XMonad.StackSet                as W
 import qualified XMonad.Util.Rectangle          as R
 
-import           Data.List
-import           Data.Monoid
 import qualified Data.Map                       as M
-import           Data.Function                  (on)
-import           Control.Applicative            ((<$>),(<*>),pure)
-import           Control.Monad                  (guard)
 
 
 -- $usage
@@ -125,7 +123,6 @@ data BorderMessage
     | ResetBorder Window
         -- ^ Reset the effects of any 'HasBorder' messages on the specified
         -- window.
-    deriving (Typeable)
 
 instance Message BorderMessage
 
@@ -147,7 +144,7 @@ data ConfigurableBorder p w = ConfigurableBorder
 -- | Only necessary with 'BorderMessage' - remove non-existent windows from the
 -- 'alwaysHidden' or 'neverHidden' lists.
 borderEventHook :: Event -> X All
-borderEventHook (DestroyWindowEvent { ev_window = w }) = do
+borderEventHook DestroyWindowEvent{ ev_window = w } = do
     broadcastMessage $ ResetBorder w
     return $ All True
 borderEventHook _ = return $ All True
@@ -156,7 +153,7 @@ instance (Read p, Show p, SetsAmbiguous p) => LayoutModifier (ConfigurableBorder
     unhook (ConfigurableBorder _ _ _ ch) = asks (borderWidth . config) >>= setBorders ch
 
     redoLayout cb@(ConfigurableBorder gh ah nh ch) lr mst wrs = do
-        let gh' wset = let lh = (hiddens gh wset lr mst wrs)
+        let gh' wset = let lh = hiddens gh wset lr mst wrs
                        in  return $ (ah `union` lh) \\ nh
         ch' <- withWindowSet gh'
         asks (borderWidth . config) >>= setBorders (ch \\ ch')
@@ -167,7 +164,7 @@ instance (Read p, Show p, SetsAmbiguous p) => LayoutModifier (ConfigurableBorder
         | Just (HasBorder b w) <- fromMessage m =
             let consNewIf l True  = if w `elem` l then Nothing else Just (w:l)
                 consNewIf l False = Just l
-            in  (ConfigurableBorder gh) <$> consNewIf ah (not b)
+            in  ConfigurableBorder gh <$> consNewIf ah (not b)
                                         <*> consNewIf nh b
                                         <*> pure ch
         | Just (ResetBorder w) <- fromMessage m =
@@ -247,34 +244,44 @@ instance SetsAmbiguous Ambiguity where
                                 $ W.screenDetail scr
                             ]
 
+            -- Find the screen containing the workspace being layouted.
+            -- (This is a list only to avoid the need to specialcase when it
+            -- can't be found or when several contain @lr@. When that happens,
+            -- the result will probably be incorrect.)
+            thisScreen = [ scr | scr <- W.screens wset
+                               , screenRect (W.screenDetail scr) `R.supersetOf` lr ]
+
             -- This originally considered all floating windows across all
-            -- workspaces. It seems more efficient to have each layout manage
-            -- its own floating windows - and equally valid though untested
-            -- against a multihead setup. In some cases the previous code would
-            -- redundantly add then remove borders from already-borderless
-            -- windows.
+            -- workspaces. It seems more efficient to have each screen manage
+            -- its own floating windows - and necessary to support the
+            -- additional OnlyLayoutFloat* variants correctly in multihead
+            -- setups. In some cases the previous code would redundantly add
+            -- then remove borders from already-borderless windows.
             floating = do
+                scr <- thisScreen
                 let wz :: Integer -> (Window,Rectangle)
                        -> (Integer,Window,Rectangle)
                     wz i (w,wr) = (i,w,wr)
                     -- For the following: in stacking order lowest -> highest.
                     ts = reverse . zipWith wz [-1,-2..] $ wrs
                     fs = zipWith wz [0..] $ do
-                        w       <- reverse . W.index $ wset
+                        w       <- reverse . W.integrate' . W.stack . W.workspace $ scr
                         Just wr <- [M.lookup w (W.floating wset)]
                         return (w,scaleRationalRect sr wr)
-                    sr = screenRect . W.screenDetail . W.current $ wset
+                    sr = screenRect . W.screenDetail $ scr
                 (i1,w1,wr1) <- fs
                 guard $ case amb of
                     OnlyLayoutFloatBelow ->
                         let vu = do
-                            gr           <- sr `R.difference` lr
-                            (i2,_w2,wr2) <- ts ++ fs
-                            guard $ i2 < i1
-                            [wr2 `R.intersects` gr]
+                                gr           <- sr `R.difference` lr
+                                (i2,_w2,wr2) <- ts ++ fs
+                                guard $ i2 < i1
+                                [wr2 `R.intersects` gr]
                         in lr == wr1 && (not . or) vu
                     OnlyLayoutFloat ->
                         lr == wr1
+                    OnlyFloat ->
+                        True
                     _ ->
                         wr1 `R.supersetOf` sr
                 return w1
@@ -284,6 +291,7 @@ instance SetsAmbiguous Ambiguity where
               | Screen <- amb = [w]
               | OnlyScreenFloat <- amb = []
               | OnlyLayoutFloat <- amb = []
+              | OnlyFloat <- amb = []
               | OnlyLayoutFloatBelow <- amb = []
               | OtherIndicated <- amb
               , let nonF = map integrate $ W.current wset : W.visible wset
@@ -302,9 +310,6 @@ data Ambiguity
         -- ^ This constructor is used to combine the borderless windows
         -- provided by the SetsAmbiguous instances from two other 'Ambiguity'
         -- data types.
-    | OnlyScreenFloat
-        -- ^ Only remove borders on floating windows that cover the whole
-        -- screen.
     | OnlyLayoutFloatBelow
         -- ^ Like 'OnlyLayoutFloat', but only removes borders if no window
         -- stacked below remains visible. Considers all floating windows on the
@@ -315,13 +320,19 @@ data Ambiguity
     | OnlyLayoutFloat
         -- ^ Only remove borders on floating windows that exactly cover the
         -- parent layout rectangle.
+    | OnlyScreenFloat
+        -- ^ Only remove borders on floating windows that cover the whole
+        -- screen.
     | Never
-        -- ^ Never remove borders when ambiguous: this is the same as
-        -- smartBorders.
+        -- ^ Like 'OnlyScreenFloat', and also remove borders of tiled windows
+        -- when not ambiguous: this is the same as 'smartBorders'.
     | EmptyScreen
         -- ^ Focus in an empty screen does not count as ambiguous.
     | OtherIndicated
         -- ^ No borders on full when all other screens have borders.
+    | OnlyFloat
+        -- ^ Remove borders on all floating windows; tiling windows of
+        -- any kinds are not affected.
     | Screen
         -- ^ Borders are never drawn on singleton screens.  With this one you
         -- really need another way such as a statusbar to detect focus.
