@@ -1,8 +1,9 @@
-{-# LANGUAGE FlexibleInstances, MultiParamTypeClasses, DeriveDataTypeable, TypeSynonymInstances #-}
+{-# LANGUAGE FlexibleInstances, MultiParamTypeClasses #-}
 
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  XMonad.Layout.Reflect
+-- Description :  Reflect a layout horizontally or vertically.
 -- Copyright   :  (c) Brent Yorgey
 -- License     :  BSD-style (see LICENSE)
 --
@@ -23,13 +24,12 @@ module XMonad.Layout.Reflect (
 
                              ) where
 
-import XMonad.Core
+import XMonad.Prelude (fi)
 import Graphics.X11 (Rectangle(..), Window)
 import Control.Arrow (second)
 
 import XMonad.Layout.LayoutModifier
 import XMonad.Layout.MultiToggle
-import XMonad.Util.XUtils (fi)
 
 -- $usage
 -- You can use this module by importing it into your @~\/.xmonad\/xmonad.hs@ file:
@@ -88,7 +88,7 @@ reflectRect Vert (Rectangle _ sy _ sh) (Rectangle rx ry rw rh) =
 
 
 
-data Reflect a = Reflect ReflectDir deriving (Show, Read)
+newtype Reflect a = Reflect ReflectDir deriving (Show, Read)
 
 instance LayoutModifier Reflect a where
 
@@ -101,8 +101,8 @@ instance LayoutModifier Reflect a where
 
 -------- instances for MultiToggle ------------------
 
-data REFLECTX = REFLECTX deriving (Read, Show, Eq, Typeable)
-data REFLECTY = REFLECTY deriving (Read, Show, Eq, Typeable)
+data REFLECTX = REFLECTX deriving (Read, Show, Eq)
+data REFLECTY = REFLECTY deriving (Read, Show, Eq)
 
 instance Transformer REFLECTX Window where
     transform REFLECTX x k = k (reflectHoriz x) (\(ModifiedLayout _ x') -> x')
