@@ -1,8 +1,9 @@
-{-# LANGUAGE FlexibleInstances, MultiParamTypeClasses #-}
+{-# LANGUAGE FlexibleInstances, MultiParamTypeClasses, TupleSections #-}
 
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  XMonad.Layout.Square
+-- Description :  A layout that splits the screen into a square area and the rest of the screen.
 -- Copyright   :  (c) David Roundy <droundy@darcs.net>
 -- License     :  BSD3-style (see LICENSE)
 --
@@ -46,7 +47,7 @@ data Square a = Square deriving ( Read, Show )
 
 instance LayoutClass Square a where
     pureLayout Square r s = arrange (integrate s)
-        where arrange ws@(_:_) = map (\w->(w,rest)) (init ws) ++ [(last ws,sq)]
+        where arrange ws@(_:_) = map (, rest) (init ws) ++ [(last ws,sq)]
               arrange [] = [] -- actually, this is an impossible case
               (rest, sq) = splitSquare r
 
