@@ -1,11 +1,12 @@
 {-# OPTIONS_GHC -fno-warn-name-shadowing -fno-warn-unused-binds #-}
 {-# LANGUAGE FlexibleInstances, MultiParamTypeClasses
-  , PatternGuards, DeriveDataTypeable, ExistentialQuantification
+  , PatternGuards, ExistentialQuantification
   , FlexibleContexts #-}
 
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  XMonad.Layout.ZoomRow
+-- Description :  Row layout with individually resizable elements.
 -- Copyright   :  Quentin Moser <moserq@gmail.com>
 -- License     :  BSD-style (see LICENSE)
 --
@@ -35,12 +36,11 @@ module XMonad.Layout.ZoomRow ( -- * Usage
                              ) where
 
 import XMonad
+import XMonad.Prelude (fromMaybe, fi)
 import qualified XMonad.StackSet as W
 
 import XMonad.Util.Stack
-import XMonad.Layout.Decoration (fi)
 
-import Data.Maybe (fromMaybe)
 import Control.Arrow (second)
 
 -- $usage
@@ -106,7 +106,7 @@ data ZoomRow f a = ZC { zoomEq ::  f a
                           -- ^ Function to compare elements for
                           -- equality, a real Eq instance might
                           -- not be what you want in some cases
-                      , zoomRatios :: (Zipper (Elt a))
+                      , zoomRatios :: Zipper (Elt a)
                           -- ^ Element specs. The zipper is so we
                           -- know what the focus is when we handle
                           --  a message
@@ -163,7 +163,7 @@ data ZoomMessage = Zoom Rational
                  | ZoomFullToggle
                  -- ^ Toggle whether the focused window should
                  -- occupy all available space when it has focus
-  deriving (Typeable, Show)
+  deriving (Show)
 
 instance Message ZoomMessage
 
@@ -185,7 +185,7 @@ zoomReset = ZoomTo 1
 
 -- * LayoutClass instance
 
-instance (EQF f a, Show a, Read a, Show (f a), Read (f a))
+instance (EQF f a, Show a, Read a, Show (f a), Read (f a), Typeable f)
     => LayoutClass (ZoomRow f) a where
     description (ZC _ Nothing) = "ZoomRow"
     description (ZC _ (Just s)) = "ZoomRow" ++ if full $ W.focus s
@@ -237,7 +237,7 @@ instance (EQF f a, Show a, Read a, Show (f a), Read (f a))
                         helper (Right a:as) (Right b:bs) = a `sameAs` b && as `helper` bs
                         helper (Left a:as) (Left b:bs) = a `sameAs` b && as `helper` bs
                         helper _ _ = False
-                        E a1 r1 b1 `sameAs` E a2 r2 b2 = (eq f a1 a2) && (r1 == r2) && (b1 == b2)
+                        E a1 r1 b1 `sameAs` E a2 r2 b2 = eq f a1 a2 && (r1 == r2) && (b1 == b2)
 
     pureMessage (ZC f zelts) sm | Just (ZoomFull False) <- fromMessage sm
                                 , Just (E a r True) <- getFocusZ zelts
@@ -255,4 +255,4 @@ instance (EQF f a, Show a, Read a, Show (f a), Read (f a))
                                      $ SomeMessage $ ZoomFull $ not b
             _ -> Nothing
 
-    pureMessage _ _ = Nothing
\ No newline at end of file
+    pureMessage _ _ = Nothing
