@@ -6,6 +6,7 @@
 {-# LANGUAGE NamedFieldPuns #-}
 {-# LANGUAGE PatternGuards #-}
 {-# LANGUAGE LambdaCase #-}
+{-# LANGUAGE ViewPatterns #-}
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  XMonad.Prompt
@@ -98,7 +99,6 @@ module XMonad.Prompt
 
 import           XMonad                       hiding (cleanMask, config)
 import           XMonad.Prelude               hiding (toList)
-import qualified XMonad                       as X (numberlockMask)
 import qualified XMonad.StackSet              as W
 import           XMonad.Util.Font
 import           XMonad.Util.Types
@@ -149,7 +149,7 @@ data XPState =
         , offset                :: !Int
         , config                :: XPConfig
         , successful            :: Bool
-        , numlockMask           :: KeyMask
+        , cleanMask             :: KeyMask -> KeyMask
         , done                  :: Bool
         , modeDone              :: Bool
         , color                 :: XPColor
@@ -270,7 +270,7 @@ class XPrompt t where
     -- The argument passed to this function is given by `commandToComplete`
     -- The default implementation shows an error message.
     completionFunction :: t -> ComplFunction
-    completionFunction t = \_ -> return ["Completions for " ++ showXPrompt t ++ " could not be loaded"]
+    completionFunction t = const $ return ["Completions for " ++ showXPrompt t ++ " could not be loaded"]
 
     -- | When the prompt has multiple modes (created with mkXPromptWithModes), this function is called
     -- when the user picks an item from the autocompletion list.
@@ -356,9 +356,9 @@ amberXPConfig = def { bgColor   = "black"
                     }
 
 initState :: Display -> Window -> Window -> Rectangle -> XPOperationMode
-          -> GC -> XMonadFont -> [String] -> XPConfig -> KeyMask -> Dimension
-          -> XPState
-initState d rw w s opMode gc fonts h c nm width =
+          -> GC -> XMonadFont -> [String] -> XPConfig -> (KeyMask -> KeyMask)
+          -> Dimension -> XPState
+initState d rw w s opMode gc fonts h c cm width =
     XPS { dpy                   = d
         , rootw                 = rw
         , win                   = w
@@ -381,7 +381,7 @@ initState d rw w s opMode gc fonts h c nm width =
         , successful            = False
         , done                  = False
         , modeDone              = False
-        , numlockMask           = nm
+        , cleanMask             = cm
         , prompter              = defaultPrompter c
         , color                 = defaultColor c
         , eventBuffer           = []
@@ -554,7 +554,7 @@ mkXPromptImplementation :: String -> XPConfig -> XPOperationMode -> X XPState
 mkXPromptImplementation historyKey conf om = do
   XConf { display = d, theRoot = rw } <- ask
   s <- gets $ screenRect . W.screenDetail . W.current . windowset
-  numlock <- gets X.numberlockMask
+  cleanMask <- cleanKeyMask
   cachedir <- asks (cacheDir . directories)
   hist <- io $ readHistory cachedir
   fs <- initXMF (font conf)
@@ -571,7 +571,7 @@ mkXPromptImplementation historyKey conf om = do
             selectInput d w $ exposureMask .|. keyPressMask
             setGraphicsExposures d gc False
             let hs = fromMaybe [] $ M.lookup historyKey hist
-                st = initState d rw w s om gc fs hs conf numlock width
+                st = initState d rw w s om gc fs hs conf cleanMask width
             runXP st))
   releaseXMF fs
   when (successful st') $ do
@@ -594,15 +594,6 @@ mkXPromptImplementation historyKey conf om = do
     CenteredAt{ xpWidth } -> floor $ fi (rect_width scr) * xpWidth
     _                     -> rect_width scr
 
--- | Removes numlock and capslock from a keymask.
--- Duplicate of cleanMask from core, but in the
--- XP monad instead of X.
-cleanMask :: KeyMask -> XP KeyMask
-cleanMask msk = do
-  numlock <- gets numlockMask
-  let highMasks = 1 `shiftL` 12 - 1
-  return (complement (numlock .|. lockMask) .&. msk .&. highMasks)
-
 -- | Inverse of 'Codec.Binary.UTF8.String.utf8Encode', that is, a convenience
 -- function that checks to see if the input string is UTF8 encoded before
 -- decoding.
@@ -646,10 +637,11 @@ eventLoop handle stopAction = do
                     -- Also capture @buttonPressMask@, see Note [Allow ButtonEvents]
                     maskEvent d (exposureMask .|. keyPressMask .|. buttonPressMask) e
                     ev <- getEvent e
-                    (ks,s) <- if ev_event_type ev == keyPress
-                              then lookupString $ asKeyEvent e
-                              else return (Nothing, "")
-                    return (fromMaybe xK_VoidSymbol ks,s,ev)
+                    if ev_event_type ev == keyPress
+                        then do (_, s) <- lookupString $ asKeyEvent e
+                                ks <- keycodeToKeysym d (ev_keycode ev) 0
+                                return (ks, s, ev)
+                        else return (noSymbol, "", ev)
         l   -> do
                 modify $ \s -> s { eventBuffer = tail l }
                 return $ head l
@@ -698,7 +690,7 @@ merely discarded, but passed to the respective application window.
 handleMain :: KeyStroke -> Event -> XP ()
 handleMain stroke@(keysym,_) KeyEvent{ev_event_type = t, ev_state = m} = do
     (compKey,modeKey) <- gets $ (completionKey &&& changeModeKey) . config
-    keymask <- cleanMask m
+    keymask <- gets cleanMask <*> pure m
     -- haven't subscribed to keyRelease, so just in case
     when (t == keyPress) $
         if (keymask,keysym) == compKey
@@ -747,7 +739,7 @@ handleCompletion cs = do
     alwaysHlight <- gets $ alwaysHighlight . config
     st <- get
 
-    let updateWins  l = redrawWindows (pure ()) l
+    let updateWins    = redrawWindows (pure ())
         updateState l = if alwaysHlight
             then hlComplete (getLastWord $ command st) l st
             else simpleComplete                        l st
@@ -830,7 +822,7 @@ handleSubmap :: XP ()
              -> Event
              -> XP ()
 handleSubmap defaultAction keymap stroke KeyEvent{ev_event_type = t, ev_state = m} = do
-    keymask <- cleanMask m
+    keymask <- gets cleanMask <*> pure m
     when (t == keyPress) $ handleInputSubmap defaultAction keymap keymask stroke
 handleSubmap _ _ stroke event = handleOther stroke event
 
@@ -887,7 +879,7 @@ handleBuffer :: (String -> String -> (Bool,Bool))
              -> Event
              -> XP ()
 handleBuffer f stroke event@KeyEvent{ev_event_type = t, ev_state = m} = do
-    keymask <- cleanMask m
+    keymask <- gets cleanMask <*> pure m
     when (t == keyPress) $ handleInputBuffer f keymask stroke event
 handleBuffer _ stroke event = handleOther stroke event
 
@@ -1016,6 +1008,7 @@ emacsLikeXPKeymap' p = M.fromList $
   , (xK_y, pasteString)
   , (xK_g, quit)
   , (xK_bracketleft, quit)
+  , (xK_t, transposeChars)
   ] ++
   map (first $ (,) mod1Mask) -- meta key + <key>
   [ (xK_BackSpace, killWord' p Prev)
@@ -1227,6 +1220,23 @@ changeWord p = join $ f <$> getInput <*> getOffset <*> pure p
         f str off p'| p' $ str !! off       = killWord' (not . p') Next
                     | otherwise             = killWord' p' Next
 
+-- | Interchange characters around point, moving forward one character
+--   if not at the end of the input.
+transposeChars :: XP ()
+transposeChars = do
+  off <- gets offset
+  cmd <- gets command
+  let (beforeCursor, afterCursor) = splitAt off cmd
+      (ncom, noff) = fromMaybe (cmd, off) (go beforeCursor afterCursor off)
+  modify $ \s -> setCommand ncom $ s{ offset = noff }
+ where
+  go :: [a] -> [a] -> Int -> Maybe ([a], Int)
+  go (reverse -> (b1 : b2 : bs)) [] offset =  -- end of line
+    Just (reverse $ b2 : b1 : bs, offset)
+  go (reverse -> (b : bs)) (a : as) offset =  -- middle of line
+    Just (reverse (a : bs) ++ b : as, offset + 1)
+  go _ _ _ = Nothing
+
 -- | Put the cursor at the end of line
 endOfLine :: XP ()
 endOfLine  =
