@@ -1,6 +1,7 @@
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  XMonad.Prompt.DirExec
+-- Description :  A directory file executables prompt for XMonad.
 -- Copyright   :  (C) 2008 Juraj Hercek
 -- License     :  BSD3
 --
@@ -26,9 +27,8 @@ module XMonad.Prompt.DirExec
 
 import Control.Exception as E
 import System.Directory
-import Control.Monad
-import Data.List
 import XMonad
+import XMonad.Prelude
 import XMonad.Prompt
 
 econst :: Monad m => a -> IOException -> m a
@@ -65,7 +65,7 @@ econst = const . return
 -- For detailed instruction on editing the key binding see
 -- "XMonad.Doc.Extending#Editing_key_bindings".
 
-data DirExec = DirExec String
+newtype DirExec = DirExec String
 
 instance XPrompt DirExec where
     showXPrompt (DirExec name) = name
@@ -100,7 +100,7 @@ getDirectoryExecutables :: FilePath -> IO [String]
 getDirectoryExecutables path =
     (getDirectoryContents path >>=
         filterM (\x -> let x' = path ++ x in
-            liftM2 (&&)
+            liftA2 (&&)
                 (doesFileExist x')
-                (liftM executable (getPermissions x'))))
+                (fmap executable (getPermissions x'))))
     `E.catch` econst []
