@@ -1,6 +1,7 @@
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  XMonad.Prompt.Email
+-- Description :  A prompt for sending quick, one-line emails, via GNU \'mail\'.
 -- Copyright   :  (c) 2007 Brent Yorgey
 -- License     :  BSD-style (see LICENSE)
 --
@@ -23,6 +24,7 @@ module XMonad.Prompt.Email (
 
 import XMonad.Core
 import XMonad.Util.Run
+import XMonad.Prelude (void)
 import XMonad.Prompt
 import XMonad.Prompt.Input
 
@@ -56,8 +58,7 @@ import XMonad.Prompt.Input
 --   of addresses for autocompletion.
 emailPrompt :: XPConfig -> [String] -> X ()
 emailPrompt c addrs =
-    inputPromptWithCompl c "To" (mkComplFunFromList addrs) ?+ \to ->
+    inputPromptWithCompl c "To" (mkComplFunFromList c addrs) ?+ \to ->
     inputPrompt c "Subject" ?+ \subj ->
     inputPrompt c "Body" ?+ \body ->
-    runProcessWithInput "mail" ["-s", subj, to] (body ++ "\n")
-         >> return ()
+    void (runProcessWithInput "mail" ["-s", subj, to] (body ++ "\n"))
