@@ -1,6 +1,7 @@
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  XMonad.Prompt.Input
+-- Description :  Prompt the user for input and pass it along to some other action.
 -- Copyright   :  (c) 2007 Brent Yorgey
 -- License     :  BSD-style (see LICENSE)
 --
@@ -49,12 +50,12 @@ import XMonad.Prompt
 -- @fireEmployee@ action, like so:
 --
 -- > firingPrompt :: X ()
--- > firingPrompt = inputPrompt defaultXPConfig "Fire" ?+ fireEmployee
+-- > firingPrompt = inputPrompt def "Fire" ?+ fireEmployee
 --
 -- If @employees@ contains a list of all his employees, he could also
 -- create an autocompleting version, like this:
 --
--- > firingPrompt' = inputPromptWithCompl defaultXPConfig "Fire"
+-- > firingPrompt' = inputPromptWithCompl def "Fire"
 -- >                     (mkComplFunFromList employees) ?+ fireEmployee
 --
 -- Now all he has to do is add a keybinding to @firingPrompt@ (or
@@ -77,7 +78,7 @@ import XMonad.Prompt
 -- "XMonad.Prompt.Email", which prompts the user for a recipient,
 -- subject, and one-line body, and sends a quick email.
 
-data InputPrompt = InputPrompt String
+newtype InputPrompt = InputPrompt String
 
 instance XPrompt InputPrompt  where
     showXPrompt (InputPrompt s) = s ++ ": "
