@@ -1,6 +1,7 @@
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  XMonad.Prompt.RunOrRaise
+-- Description :  A prompt to run a program, open a file, or raise a running program.
 -- Copyright   :  (C) 2008 Justin Bogner
 -- License     :  BSD3
 --
@@ -21,14 +22,14 @@ module XMonad.Prompt.RunOrRaise
     ) where
 
 import XMonad hiding (config)
+import XMonad.Prelude (isNothing, isSuffixOf, liftA2)
 import XMonad.Prompt
 import XMonad.Prompt.Shell
 import XMonad.Actions.WindowGo (runOrRaise)
 import XMonad.Util.Run (runProcessWithInput)
 
 import Control.Exception as E
-import Control.Monad (liftM, liftM2)
-import System.Directory (doesDirectoryExist, doesFileExist, executable, getPermissions)
+import System.Directory (doesDirectoryExist, doesFileExist, executable, findExecutable, getPermissions)
 
 econst :: Monad m => a -> IOException -> m a
 econst = const . return
@@ -59,15 +60,20 @@ open path = io (isNormalFile path) >>= \b ->
             then spawn $ "xdg-open \"" ++ path ++ "\""
             else uncurry runOrRaise . getTarget $ path
     where
-      isNormalFile f = exists f >>= \e -> if e then notExecutable f else return False
-      exists f = fmap or $ sequence [doesFileExist f,doesDirectoryExist f]
+      isNormalFile f = do
+          notCommand <- isNothing <$> findExecutable f -- not a command (executable in $PATH)
+          exists <- or <$> sequence [doesDirExist f, doesFileExist f]
+          case (notCommand, exists) of
+              (True, True) -> notExecutable f -- not executable as a file in current dir
+              _            -> pure False
       notExecutable = fmap (not . executable) . getPermissions
+      doesDirExist f = ("/" `isSuffixOf` f &&) <$> doesDirectoryExist f
       getTarget x = (x,isApp x)
 
 isApp :: String -> Query Bool
 isApp "firefox"     = className =? "Firefox-bin"     <||> className =? "Firefox"
 isApp "thunderbird" = className =? "Thunderbird-bin" <||> className =? "Thunderbird"
-isApp x = liftM2 (==) pid $ pidof x
+isApp x = liftA2 (==) pid $ pidof x
 
 pidof :: String -> Query Int
 pidof x = io $ (runProcessWithInput "pidof" [x] [] >>= readIO) `E.catch` econst 0
@@ -75,7 +81,7 @@ pidof x = io $ (runProcessWithInput "pidof" [x] [] >>= readIO) `E.catch` econst
 pid :: Query Int
 pid = ask >>= (\w -> liftX $ withDisplay $ \d -> getPID d w)
     where getPID d w = getAtom "_NET_WM_PID" >>= \a -> io $
-                       liftM getPID' (getWindowProperty32 d a w)
+                       fmap getPID' (getWindowProperty32 d a w)
           getPID' (Just (x:_)) = fromIntegral x
-          getPID' (Just [])     = -1
-          getPID' (Nothing)     = -1
+          getPID' (Just [])    = -1
+          getPID' Nothing      = -1
