@@ -1,6 +1,7 @@
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  XMonad.Prompt.Ssh
+-- Description :  An ssh prompt.
 -- Copyright   :  (C) 2007 Andrea Rossato
 -- License     :  BSD3
 --
@@ -20,6 +21,7 @@ module XMonad.Prompt.Ssh
     ) where
 
 import XMonad
+import XMonad.Prelude
 import XMonad.Util.Run
 import XMonad.Prompt
 
@@ -27,10 +29,6 @@ import System.Directory
 import System.Environment
 import Control.Exception as E
 
-import Control.Monad
-import Data.Maybe
-import Data.List(elemIndex)
-
 econst :: Monad m => a -> IOException -> m a
 econst = const . return
 
@@ -54,22 +52,22 @@ data Ssh = Ssh
 
 instance XPrompt Ssh where
     showXPrompt       Ssh = "SSH to: "
-    commandToComplete _ c = maybe c (\(_u,h) -> h) (parseHost c)
+    commandToComplete _ c = maybe c snd (parseHost c)
     nextCompletion _t c l = maybe next (\(u,_h) -> u ++ "@" ++ next) hostPared
-                            where 
+                            where
                               hostPared = parseHost c
-                              next = getNextCompletion (maybe c (\(_u,h) -> h) hostPared) l
+                              next = getNextCompletion (maybe c snd hostPared) l
 
 sshPrompt :: XPConfig -> X ()
 sshPrompt c = do
   sc <- io sshComplList
-  mkXPrompt Ssh c (mkComplFunFromList sc) ssh
+  mkXPrompt Ssh c (mkComplFunFromList c sc) ssh
 
 ssh :: String -> X ()
 ssh = runInTerm "" . ("ssh " ++ )
 
 sshComplList :: IO [String]
-sshComplList = uniqSort `fmap` liftM2 (++) sshComplListLocal sshComplListGlobal
+sshComplList = uniqSort <$> liftA2 (++) sshComplListLocal sshComplListGlobal
 
 sshComplListLocal :: IO [String]
 sshComplListLocal = do
@@ -141,4 +139,4 @@ getWithPort ('[':str) = host ++ " -p " ++ port
 getWithPort  str = str
 
 parseHost :: String -> Maybe (String, String)
-parseHost a = elemIndex '@' a  >>= (\c-> Just ( (take c a), (drop (c+1) a) ) )
+parseHost a = elemIndex '@' a  >>= (\c-> Just ( take c a, drop (c+1) a ) )
