@@ -1,6 +1,7 @@
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  XMonad.Prompt.Theme
+-- Description :  A prompt for changing the theme of the current workspace.
 -- Copyright   :  (C) 2007 Andrea Rossato
 -- License     :  BSD3
 --
@@ -20,7 +21,7 @@ module XMonad.Prompt.Theme
 
 import Control.Arrow ( (&&&) )
 import qualified Data.Map as M
-import Data.Maybe ( fromMaybe )
+import XMonad.Prelude ( fromMaybe )
 import XMonad
 import XMonad.Prompt
 import XMonad.Layout.Decoration
@@ -48,7 +49,7 @@ instance XPrompt ThemePrompt where
     nextCompletion      _ = getNextCompletion
 
 themePrompt :: XPConfig -> X ()
-themePrompt c = mkXPrompt ThemePrompt c (mkComplFunFromList' . map ppThemeInfo $ listOfThemes) changeTheme
+themePrompt c = mkXPrompt ThemePrompt c (mkComplFunFromList' c . map ppThemeInfo $ listOfThemes) changeTheme
     where changeTheme t = sendMessage . SetTheme . fromMaybe def $ M.lookup t mapOfThemes
 
 mapOfThemes :: M.Map String Theme
