@@ -1,6 +1,7 @@
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  XMonad.Prompt.Workspace
+-- Description :  A workspace prompt.
 -- Copyright   :  (C) 2007 Andrea Rossato, David Roundy
 -- License     :  BSD3
 --
@@ -37,7 +38,7 @@ import XMonad.Util.WorkspaceCompare ( getSortByIndex )
 -- For detailed instruction on editing the key binding see
 -- "XMonad.Doc.Extending#Editing_key_bindings".
 
-data Wor = Wor String
+newtype Wor = Wor String
 
 instance XPrompt Wor where
     showXPrompt (Wor x) = x
@@ -46,4 +47,4 @@ workspacePrompt :: XPConfig -> (String -> X ()) -> X ()
 workspacePrompt c job = do ws <- gets (workspaces . windowset)
                            sort <- getSortByIndex
                            let ts = map tag $ sort ws
-                           mkXPrompt (Wor "") c (mkComplFunFromList' ts) job
+                           mkXPrompt (Wor "") c (mkComplFunFromList' c ts) job
