@@ -53,7 +53,7 @@ module XMonad.Util.PureX (
 
 -- xmonad
 import XMonad
-import XMonad.Prelude (Any (..), liftA2)
+import XMonad.Prelude (Any (..), liftA2, WindowScreen)
 import qualified XMonad.StackSet as W
 import qualified XMonad.Actions.FocusNth
 
@@ -115,7 +115,6 @@ instance Semigroup a => Semigroup (PureX a) where
   (<>) = liftA2 (<>)
 
 instance Monoid a => Monoid (PureX a) where
-  mappend = liftA2 mappend
   mempty  = return mempty
 
 -- | The @XLike@ typeclass over monads reading @XConf@ values and tracking
@@ -221,9 +220,7 @@ peek :: XLike m => m (Maybe Window)
 peek = withWindowSet' (return . W.peek)
 
 -- | Get the current screen.
-curScreen
-  :: XLike m
-  => m (W.Screen WorkspaceId (Layout Window) Window ScreenId ScreenDetail)
+curScreen :: XLike m => m WindowScreen
 curScreen = withWindowSet' (return . W.current)
 
 -- | Get the current workspace.
